Security Advisories (1)
CVE-2022-1664 (2022-05-26)

Dpkg::Source::Archive in dpkg, the Debian package management system, before version 1.21.8, 1.20.10, 1.19.8, 1.18.26 is prone to a directory traversal vulnerability. When extracting untrusted source packages in v2 and v3 source package formats that include a debian.tar, the in-place extraction can lead to directory traversal situations on specially crafted orig.tar and debian.tar tarballs.

NAME

Dpkg::Deps::Union - list of unrelated dependencies

DESCRIPTION

This class represents a list of relationships. It inherits from Dpkg::Deps::Multiple.

METHODS

$dep->output([$fh])

The output method uses ", " to join the list of relationships.

$dep->implies($other_dep)
$dep->get_evaluation($other_dep)

These methods are not meaningful for this object and always return undef.

$dep->simplify_deps($facts)

The simplification is done to generate an union of all the relationships. It uses $simple_dep->merge_union($other_dep) to get its job done.

CHANGES

Version 1.00 (dpkg 1.15.6)

Mark the module as public.